@@ -97,9 +97,11 @@ static bool activate(int argc, char **args)
 		delete addr;
 		return false;
 	}
+	time(&reg->created);
 	if(!reg->setTargets(*addr))
 		rtn = false;
 	registry::detach(reg);
+	service::activate(reg);
 	delete addr;
 	return rtn;
 }
@@ -243,10 +245,12 @@ void server::run(const char *user)
 {
 	int argc;
 	char *argv[65];
+	char *state;
 	char *cp, *tokens;
 	static int exit_code = 0;
 	time_t now;
 	struct tm *dt, hold;
+	FILE *fp;
 
 	time(&now);
 	dt = localtime_r(&now, &hold);
@@ -314,6 +318,22 @@ invalid:
 			continue;
 		}
 
+		if(!stricmp(argv[0], "state")) {
+			if(argc != 2)
+				goto invalid;
+			state = String::unquote(argv[1], "\"\"\'\'()[]{}");
+			if(!service::state(state))
+				process::reply("invalid state");
+			fp = fopen(DEFAULT_VARPATH "/run/sipwitch/state.def", "w");
+			if(fp) {
+				fputs(state, fp);
+				fclose(fp);
+			}
+			process::errlog(NOTICE, "state changed to %s", state);
+			config::reload(user);
+			continue;
+		}
+
 		if(!stricmp(argv[0], "concurrency")) {
 			if(argc != 2)
 				goto invalid;
@@ -423,6 +443,7 @@ void server::usage(void)
 		"  message <user> <text> Send instant message to user agent\n"
 		"  digest <user> <pass>  Compute digest based on server realm\n"
 		"  registry              List registrations from shared memory\n"
+		"  state <level>         Set server running state\n"
 		"  activate <user>       Activate static user registration\n"
 		"  release <user>        Release registered user\n"
 #endif
